@@ -3,6 +3,7 @@ import io
 import json
 import numpy as np
 import requests
+import secrets
 import time
 import uuid
 import webbrowser
@@ -74,6 +75,7 @@ class InputData:
         try:
             if label == "operator":
                 operator = content
+                self.validate_operator(operator)
                 coeffs = None
                 if type(content) == tuple:
                     operator, coeffs = content
@@ -123,33 +125,29 @@ class InputData:
             )
 
     def validate_molecule_info(self, molecule_info):
-        if not isinstance(
-            molecule_info["symbols"], list
-        ):
-            raise Exception("Symmbols must be a list of nuclei.")
-        if not isinstance(
-            molecule_info["coords"], list
-        ):
-            raise Exception("Coords must be a list of tuples representing the x, y, z position of each nuclei.")
+        if not isinstance(molecule_info["symbols"], list):
+            raise Exception("The 'symbols' must be a list of nuclei.")
+        if not isinstance(molecule_info["coords"], list):
+            raise Exception(
+                "The 'coords' must be a list of tuples representing the x, y, z position of each nuclei."
+            )
         if "mutiplicity" in molecule_info and not isinstance(
             molecule_info["mutiplicity"], int
         ):
-            raise Exception("Multiplicity must be an integer.")
+            raise Exception("The 'multiplicity' must be an integer.")
         if "charge" in molecule_info and not isinstance(molecule_info["charge"], int):
-            raise Exception("Charge must be an integer.")
+            raise Exception("The 'charge' must be an integer.")
         if (
             "units" in molecule_info
             and molecule_info["units"].lower() != "angstrom"
             and molecule_info["units"].lower() != "bohr"
         ):
-            raise Exception(
-                "The units of the molecule coordinates must be either 'Angstrom' or 'Bohr'."
-            )
+            raise Exception("The 'units' must be either 'Angstrom' or 'Bohr'.")
         if "masses" in molecule_info and not all(
             isinstance(m, (int, float)) for m in molecule_info["masses"]
         ):
             raise Exception(
-                "Masses must be a list of floats, one for each nucleus in the molecule."
+                "The 'masses' must be a list of floats, one for each nucleus in the molecule."
             )
 
     def validate_and_serialize_pub(self, pub):
@@ -200,7 +198,7 @@ class InputData:
 
         return (serialize_circuit(quantum_circuit), paramaters, shots)
 
-    def validate_and_serialize_operator(self, operator):
+    def validate_operator(self, operator):
         if (
             not isinstance(operator, Operator)
             and not isinstance(operator, Pauli)
@@ -237,8 +235,6 @@ class InputData:
                     "The number of Pauli terms in the Pauli list must match the number of coefficients or list of coefficients must be empty."
                 )
 
-        return serialize_circuit(operator)
-
     def to_sparse_pauli_operator(self, operator, coeffs=None):
         if isinstance(operator, SparsePauliOp):
             return operator
@@ -638,13 +634,7 @@ In case the service has been recently started please wait 5 minutes for it to be
             return False
 
     def _store_state(self):
-        state = str(uuid.uuid4())
-        #session = requests.Session()
-        # session_response = session.put(
-        #     f"{self._asp_net_url}/auth/storestate",
-        #     params={"state": state},
-        #     verify=self._use_https,
-        # )
+        state = secrets.token_urlsafe(64)
         response = requests.post(
             f"{self._asp_net_url}/auth/storestate",
             json={"state": state},
